#
# spec file for package grant
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           grant
Version:        0.2.8
Release:        1.1
Summary:        Search an SBOM for licenses and the packages they belong to
License:        Apache-2.0
URL:            https://github.com/anchore/grant
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  zsh
BuildRequires:  golang(API) >= 1.24

%description
View licenses for container images, SBOM documents, filesystems, and apply
rules that help you build a license compliance report.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")

go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X main.version=%{version} \
   -X main.gitCommit=${COMMIT_HASH} \
   -X main.gitDescription=v%{version} \
   -X main.buildDate=$BUILD_DATE" \
   -o bin/%{name} ./cmd/%{name}

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Thu Jul 24 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.2.8:
  * chore: update credentials for release (#227)
  * chore(deps): update anchore dependencies (#226)
  * chore(deps): bump github.com/charmbracelet/bubbletea from 1.3.5
    to 1.3.6 (#224)
  * chore: lint gh actions with zizmor (#225)
  * chore(deps): update anchore dependencies (#223)
  * chore(deps): bump github.com/go-viper/mapstructure/v2 (#221)
  * chore(deps): bump github.com/anchore/syft from 1.27.0 to 1.27.1
    (#220)
  * chore(deps): bump github.com/anchore/syft from 1.26.1 to 1.27.0
    (#219)
  * chore(deps): bump github.com/anchore/stereoscope from 0.1.4 to
    0.1.5 (#218)
  * chore(deps): bump github.com/gkampitakis/go-snaps from 0.5.12
    to 0.5.13 (#216)
  * chore(deps): bump github.com/anchore/syft from 1.24.0 to 1.26.1
    (#212)
  * chore(deps): bump github.com/gkampitakis/go-snaps from 0.5.11
    to 0.5.12 (#213)
  * chore(deps): bump github.com/anchore/syft from 1.23.1 to 1.24.0
    (#207)
  * chore(deps): bump github.com/github/go-spdx/v2 from 2.3.2 to
    2.3.3 (#206)
* Wed Apr 30 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.2.7:
  * chore(deps): bump github.com/anchore/syft from 1.23.0 to 1.23.1
    (#203)
  * chore(deps): update anchore dependencies (#202)
  * feat: bump go version (#201)
  * chore(deps): bump github.com/anchore/stereoscope from 0.1.2 to
    0.1.3 (#199)
  * chore(deps): bump golang.org/x/net from 0.36.0 to 0.38.0 (#200)
  * chore(deps): bump github.com/anchore/stereoscope (#198)
  * chore(deps): bump github.com/containerd/containerd from 1.7.24
    to 1.7.27 (#193)
  * chore(deps): bump github.com/google/go-cmp from 0.6.0 to 0.7.0
    (#186)
  * chore(deps): bump github.com/jedib0t/go-pretty/v6 from 6.6.6 to
    6.6.7 (#190)
  * chore(deps): bump golang.org/x/net from 0.35.0 to 0.36.0 (#191)
  * chore(deps): bump github.com/charmbracelet/bubbletea from 1.3.3
    to 1.3.4 (#189)
  * chore(deps): bump github.com/charmbracelet/lipgloss from 1.0.0
    to 1.1.0 (#192)
  * chore(deps): bump github.com/anchore/syft from 1.19.0 to 1.20.0
    (#187)
  * chore: cache update (#185)
  * chore(deps): bump github.com/gkampitakis/go-snaps from 0.5.10
    to 0.5.11 (#184)
  * chore(deps): bump github.com/charmbracelet/bubbletea from 1.3.0
    to 1.3.3 (#181)
  * feat: update to go 1.24.x (#182)
  * chore(deps): bump github.com/jedib0t/go-pretty/v6 from 6.6.5 to
    6.6.6 (#180)
  * chore(deps): bump github.com/gkampitakis/go-snaps from 0.5.9 to
    0.5.10 (#178)
  * chore(deps): bump github.com/charmbracelet/bubbletea from 1.2.4
    to 1.3.0 (#177)
  * chore(deps): bump github.com/gkampitakis/go-snaps from 0.5.8 to
    0.5.9 (#175)
  * chore(deps): update anchore dependencies (#174)
* Thu Jan 23 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.2.6:
  * chore: update token to use oss tooling; (#173)
  * chore(deps): update anchore dependencies (#172)
  * chore(deps): bump github.com/anchore/stereoscope from 0.0.12 to
    0.0.13 (#171)
  * chore(deps): bump github.com/anchore/stereoscope from 0.0.11 to
    0.0.12 (#170)
  * chore(deps): bump github.com/gkampitakis/go-snaps from 0.5.7 to
    0.5.8 (#169)
  * chore(deps): bump github.com/jedib0t/go-pretty/v6 from 6.6.4 to
    6.6.5 (#168)
* Sun Dec 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.2.5:
  * chore: update syft/stereoscope for release (#167)
  * chore(deps): bump golang.org/x/crypto from 0.30.0 to 0.31.0
    (#166)
  * add update anchore dependencies workflow (#165)
  * chore(deps): bump github.com/jedib0t/go-pretty/v6 from 6.6.2 to
    6.6.4 (#163)
  * chore(deps): bump github.com/anchore/syft from 1.17.0 to 1.18.0
    (#164)
  * chore(deps): bump github.com/charmbracelet/bubbletea from 1.2.3
    to 1.2.4 (#159)
  * chore(deps): bump github.com/stretchr/testify from 1.9.0 to
    1.10.0 (#158)
* Fri Dec  6 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.2.4:
  * dependencies: latest syft and stereoscope (#156)
  * chore(deps): bump github.com/charmbracelet/bubbletea from 1.2.2
    to 1.2.3 (#155)
  * chore(deps): bump github.com/jedib0t/go-pretty/v6 from 6.6.1 to
    6.6.2 (#153)
  * chore(deps): bump github.com/anchore/stereoscope (#150)
  * chore(deps): bump github.com/charmbracelet/bubbletea from 1.1.2
    to 1.2.2 (#152)
  * chore: update trigger-release.sh same as syft/grype (#148)
  * chore(deps): bump github.com/anchore/syft from 1.14.2 to 1.16.0
    (#147)
  * Changed exclusions to exceptions (#142)
  * chore(deps): bump github.com/charmbracelet/lipgloss from 0.13.1
    to 1.0.0 (#146)
  * chore(deps): bump github.com/anchore/stereoscope (#145)
  * chore(deps): bump github.com/charmbracelet/lipgloss (#141)
  * chore(deps): bump github.com/charmbracelet/bubbletea from 1.1.1
    to 1.1.2 (#143)
  * chore(deps): bump github.com/anchore/syft from 1.14.1 to 1.14.2
    (#140)
  * chore(deps): bump github.com/jedib0t/go-pretty/v6 from 6.6.0 to
    6.6.1 (#138)
* Fri Dec  6 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.2.3:
  * update syft to v1.14.1 (#137)
  * add release docs (#134)
  * chore(deps): bump github.com/anchore/syft from 1.13.0 to 1.14.0
    (#133)
* Fri Dec  6 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.2.2:
  * feature: add support for allowlists (#123)
  * fix: Update to support #101 (#124)
  * chore: bump go version for build (#132)
  * chore(deps): bump github.com/anchore/syft from 1.11.1 to 1.13.0
    (#129)
  * add awaiting response management (#130)
  * chore(deps): bump github.com/jedib0t/go-pretty/v6 from 6.5.9 to
    6.6.0 (#131)
  * chore(deps): bump github.com/anchore/syft from 1.11.0 to 1.11.1
    (#116)
  * chore(deps): bump github.com/charmbracelet/bubbletea (#114)
  * chore(deps): bump github.com/anchore/syft from 1.10.0 to 1.11.0
    (#113)
  * chore(deps): bump github.com/gkampitakis/go-snaps from 0.5.6 to
    0.5.7 (#112)
  * chore(deps): bump github.com/anchore/syft from 1.9.0 to 1.10.0
    (#111)
  * chore(deps): bump github.com/docker/docker (#110)
  * chore(deps): bump github.com/gkampitakis/go-snaps from 0.5.5 to
    0.5.6 (#109)
  * chore(deps): bump github.com/anchore/syft from 1.8.0 to 1.9.0
    (#103)
  * chore: Add issue templates (#107)
  * docs: CODE_OF_CONDUCT.md (#106)
  * chore(deps): bump github.com/charmbracelet/lipgloss (#105)
  * chore(deps): bump github.com/gkampitakis/go-snaps from 0.5.4 to
    0.5.5 (#108)
  * chore(deps): bump github.com/charmbracelet/lipgloss (#102)
* Thu Jul 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.2.1:
  * fix: allow brew release (#100)
  * chore: update wait for check to use latest node
  * chore: rename token to internal scheme (#99)
  * chore(deps): bump github.com/charmbracelet/bubbletea (#96)
  * chore(deps): bump github.com/anchore/syft from 1.7.0 to 1.8.0 (#97)
  * chore(deps): bump github.com/anchore/syft from 1.5.0 to 1.7.0 (#93)
  * chore(deps): bump github.com/github/go-spdx/v2 from 2.2.0 to 2.3.1 (#94)
  * chore(deps): bump github.com/spf13/cobra from 1.8.0 to 1.8.1 (#92)
  * chore(deps): bump github.com/anchore/syft from 1.4.1 to 1.5.0 (#89)
  * chore(deps): bump github.com/charmbracelet/bubbletea (#90)
* Thu Jul 11 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package grant: search an SBOM for licenses and the packages
  they belong to
